function in_data = fem_input

% fem_input.m - input file for FEM analysis  

% 1-D deformation problem. 3 nodes and two 2-node bar/pipe elements 

% Control Data: [   nodes            % Total number of nodes
%                   numel            % Total number of elements
%                   nodaldof1        % Max dof per node
%                   nodesperelement  % Max nodes per element
%                   numat            % Max mumber of materials
%                   ndimensions      % Number of space dimensions  ]

in_data.control = [4 3 1 2 2 1 ];

% Nodal Data: [ node# x1 x2 x3] 
in_data.ND = [   
   1   3.0;
   2   2.0;
   3   1.0;
   4   0.0 ];
   
% Material Property Data: [ 
%                      Element type for material no. 1
%                      Element parameter 1 (Modulus)
%                      Element parameter 2 (Cross-sectional area)
%                      Element parameter 3
%                      Element parameter 4
%                      Element parameter 5
 in_data.mater = [14   1e+09 1 0 0 0;
                  14 0.1e+09 1 0 0 0];                   

% Element Association Data: [ element# materialtype# node1# node2# ....] 
in_data.EL = [  
   1   1   1   2;
   2   1   2   3;
   3   2   3   4]; 
   
% Nodal Constraint Data: [ node# x1_disp x2_disp.... etc ] 
% 1 = fixed displacement; 0 = non-fixed displacement
in_data.CON = [  
   1   1;
   2   0;
   3   0;
   4   1];

% Nodal Load Data: [node# x1_load x2_load..... etc] 
% Magnitude of prescribed load OR displacement
in_data.LOAD = [ 
   1   0e0;
   2   0e0;
   3   10e3;
   4   0e0 ];

 